From fa97dc31c603dda19efa6845659cb5f62fedcd88 Mon Sep 17 00:00:00 2001
From: DABH <DABH@users.noreply.github.com>
Date: Sat, 12 Feb 2022 00:36:04 -0600
Subject: [PATCH] Rename package and replace CI with GitHub Actions

---
 .github/dependabot.yml   | 10 ++++++++++
 .github/workflows/ci.yml | 34 ++++++++++++++++++++++++++++++++++
 LICENSE                  |  1 +
 README.md                |  8 ++++----
 package.json             |  4 ++--
 5 files changed, 51 insertions(+), 6 deletions(-)
 create mode 100644 .github/dependabot.yml
 create mode 100644 .github/workflows/ci.yml

diff --git a/.github/dependabot.yml b/.github/dependabot.yml
new file mode 100644
index 0000000..2750076
--- /dev/null
+++ b/.github/dependabot.yml
@@ -0,0 +1,10 @@
+version: 2
+updates:
+  - package-ecosystem: github-actions
+    directory: /
+    schedule:
+      interval: weekly
+  - package-ecosystem: npm
+    directory: /
+    schedule:
+      interval: weekly
diff --git a/.github/workflows/ci.yml b/.github/workflows/ci.yml
new file mode 100644
index 0000000..354ee99
--- /dev/null
+++ b/.github/workflows/ci.yml
@@ -0,0 +1,34 @@
+name: CI
+
+on:
+  pull_request:
+    branches:
+      - main
+      - master
+  push:
+    branches:
+      - main
+      - master
+
+jobs:
+  unit-tests:
+    runs-on: ubuntu-latest
+    strategy:
+      matrix:
+        node:
+          - 12
+          - 14
+          - 16
+    steps:
+      - uses: actions/checkout@v2
+      - uses: actions/setup-node@v2
+        with:
+          node-version: ${{ matrix.node }}
+      - name: Install Dependencies
+        run: npm clean-install
+      - name: Lint
+        run: npm run lint
+      - name: Test
+        run: npm test
+      - name: TypeScript Test
+        run: npx --package typescript tsc
diff --git a/LICENSE b/LICENSE
index 17880ff..6b86056 100644
--- a/LICENSE
+++ b/LICENSE
@@ -5,6 +5,7 @@ Original Library
 
 Additional Functionality
  - Copyright (c) Sindre Sorhus <sindresorhus@gmail.com> (sindresorhus.com)
+ - Copyright (c) DABH (https://github.com/DABH)
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
diff --git a/README.md b/README.md
index 7bca887..3d3ce54 100644
--- a/README.md
+++ b/README.md
@@ -1,8 +1,8 @@
 # colors.js
-[![Build Status](https://travis-ci.org/Marak/colors.js.svg?branch=master)](https://travis-ci.org/Marak/colors.js)
+[![Build Status](https://github.com/DABH/colors.js/actions/workflows/ci.yml/badge.svg)](https://github.com/DABH/colors.js/actions/workflows/ci.yml)
 [![version](https://img.shields.io/npm/v/colors.svg)](https://www.npmjs.org/package/@dabh/colors)
 
-Please check out the [roadmap](ROADMAP.md) for upcoming features and releases.  Please open Issues to provide feedback, and check the `develop` branch for the latest bleeding-edge updates.
+Please check out the [roadmap](ROADMAP.md) for upcoming features and releases.  Please open Issues to provide feedback.
 
 ## get color and style in your node.js console
 
@@ -140,9 +140,9 @@ colors.disable();
 ## Console.log [string substitution](http://nodejs.org/docs/latest/api/console.html#console_console_log_data)
 
 ```js
-var name = 'Marak';
+var name = 'Beowulf';
 console.log(colors.green('Hello %s'), name);
-// outputs -> 'Hello Marak'
+// outputs -> 'Hello Beowulf'
 ```
 
 ## Custom themes
diff --git a/package.json b/package.json
index ab0470f..cf584ed 100644
--- a/package.json
+++ b/package.json
@@ -1,8 +1,8 @@
 {
-    "name": "@dabh/colors",
+    "name": "@colors/colors",
     "description": "get colors in your node.js console",
     "version": "1.4.0",
-    "author": "Marak Squires",
+    "author": "DABH",
     "contributors": [
         {
             "name": "DABH",
